pub struct PiconetMember { /* private fields */ }Implementations
Sourceimpl PiconetMember
impl PiconetMember
pub fn peer_id(&self) -> PeerId
pub fn new_from_spec( mock: PiconetMemberSpec, realm: &RealmInstance, ) -> Result<Self, Error>
Sourcepub fn register_service_search(
&self,
svc_id: ServiceClassProfileIdentifier,
attributes: Vec<u16>,
) -> Result<SearchResultsRequestStream, Error>
pub fn register_service_search( &self, svc_id: ServiceClassProfileIdentifier, attributes: Vec<u16>, ) -> Result<SearchResultsRequestStream, Error>
Register a service search using the Profile protocol for services that match svc_id.
Returns a stream of search results that can be polled to receive new requests.
Sourcepub fn register_service_advertisement(
&self,
service_defs: Vec<ServiceDefinition>,
) -> Result<ConnectionReceiverRequestStream, Error>
pub fn register_service_advertisement( &self, service_defs: Vec<ServiceDefinition>, ) -> Result<ConnectionReceiverRequestStream, Error>
Register a service advertisement using the Profile protocol with the provided
service_defs.
Returns a stream of connection requests that can be polled to receive new requests.
pub async fn make_connection( &self, peer_id: PeerId, params: ConnectParameters, ) -> Result<Channel, Error>